@@ -1,11 +1,10 @@
 from ._version import __version__
 from .jobs import submit_job, McCloudSubmitJobFailure
-from .urls import generate_presigned_input_url, generate_presigned_output_url
+from .urls import generate_presigned_input_url
 
 __all__ = [
     __version__,
     submit_job,
     McCloudSubmitJobFailure,
     generate_presigned_input_url,
-    generate_presigned_output_url,
 ]
