@@ -8,14 +8,14 @@ import traceback
 import click
 from click_params import EMAIL
 
-import boto3
 from botocore.exceptions import NoCredentialsError, ProfileNotFound
 
-from .urls import generate_presigned_input_url, generate_presigned_output_url
+from .urls import generate_presigned_input_url
 from .s3_utils import split_S3_URI, validate_S3_URI, bucket_exists
 
 
 DEFAULT_API_DOMAIN = "mccloud.czi.technology"
+DEFAULT_EXPIRES_IN = 2 * 24 * 3600
 
 
 class McCloudSubmitJobFailure(Exception):
@@ -41,7 +41,7 @@ class McCloudSubmitJobFailure(Exception):
     "--output-url",
     "-o",
     required=True,
-    help="A single S3 URL which will be presigned to allow WRITE (output) access.",
+    help="A single S3 URL which McCloud has write access to.",
 )
 @click.option("--shasta-version", required=True)
 @click.option("--shasta-config", required=True)
@@ -115,16 +115,16 @@ def submit_job(
     profile_name = other_options.get("profile")
 
     mccloud_api = f"https://{domain}"
-    expires_in = 8 * 3600  # 8 hours should be plenty
+    expires_in = DEFAULT_EXPIRES_IN
     inputs = {
         "mcat": mcat,
         "email": email,
         "input_urls": list(map(lambda url: generate_presigned_input_url(url, expires_in, profile_name), input_url)),
-        "output_url": generate_presigned_output_url(output_url, expires_in, profile_name),
+        "output_url": output_url,
         "shasta_version": shasta_version,
         "shasta_ref": "",  # not currently supported in the CLI
-        "shasta_config_options": shasta_cli_opts or "",
-        "shasta_config_preset": shasta_config,
+        "shasta_commandline_options": shasta_cli_opts or "",
+        "shasta_configuration": shasta_config,
     }
 
     res = requests.post(f"{mccloud_api}/submit", json=inputs)
@@ -212,6 +212,8 @@ def validate_arguments(
         raise click.UsageError("One or more input URLs must be specified with --input-url")
     if not isinstance(output_url, str) or len(output_url) == 0:
         raise click.UsageError("One output URL must be specified.")
+    if not output_url.startswith("s3://"):
+        raise click.UsageError("Output location must be in S3.")
 
     profile_name = other_options.get("profile")
     for url in list(input_url) + [output_url]:
