@@ -5,12 +5,12 @@ import boto3
 from botocore.exceptions import ClientError
 
 
-@functools.cache
+@functools.lru_cache(maxsize=None)
 def get_aws_session(profile_name=None, region_name=None):
     return boto3.session.Session(profile_name=profile_name, region_name=region_name)
 
 
-@functools.cache
+@functools.lru_cache(maxsize=None)
 def get_aws_client(service_name, profile_name=None, region_name=None):
     return get_aws_session(profile_name, region_name).client(service_name)
 
