@@ -11,7 +11,7 @@ from .s3_utils import split_S3_URI, validate_S3_URI, bucket_exists, get_bucket_l
 McCloud CLI sub-command to generate AWS S3 presigned URLs for use in a McCloud job.
 """
 NEWLINE = "\n"
-DEFAULT_EXPIRES_IN = 8 * 3600  # in seconds
+DEFAULT_EXPIRES_IN = 2 * 24 * 3600  # in seconds
 
 
 @click.command(name="generate-s3-presigned-url", context_settings=dict(max_content_width=512))
@@ -28,12 +28,6 @@ DEFAULT_EXPIRES_IN = 8 * 3600  # in seconds
     multiple=True,
     help="S3 URL which will be presigned to allow READ (input) access.",
 )
-@click.option(
-    "--output-url",
-    "-o",
-    multiple=True,
-    help="S3 URL which will be presigned to allow WRITE (output) access.",
-)
 @click.option(
     "--expires-in",
     type=int,
@@ -41,10 +35,10 @@ DEFAULT_EXPIRES_IN = 8 * 3600  # in seconds
     show_default=True,
     help="Number of seconds until the pre-signed URLs expire.",
 )
-def generate_S3_presigned_url_cli(profile, no_confirmation, input_url, output_url, expires_in):
+def generate_S3_presigned_url_cli(profile, no_confirmation, input_url, expires_in):
     try:
-        validate_arguments(profile, input_url, output_url, expires_in)
-        make_presigned_urls(profile, input_url, output_url, expires_in, no_confirmation)
+        validate_arguments(profile, input_url, expires_in)
+        make_presigned_urls(profile, input_url, expires_in, no_confirmation)
     except ProfileNotFound as e:
         raise click.ClickException(f"AWS profile: {str(e)}") from e
     except NoCredentialsError as e:
@@ -57,7 +51,7 @@ def generate_S3_presigned_url_cli(profile, no_confirmation, input_url, output_ur
         raise click.ClickException(f"Internal error: {str(e)}") from e
 
 
-def validate_arguments(profile_name, input_urls, output_urls, expires_in):
+def validate_arguments(profile_name, input_urls, expires_in):
     """
     Validate generate_S3_presigned_url parameters.
 
@@ -70,10 +64,10 @@ def validate_arguments(profile_name, input_urls, output_urls, expires_in):
     ClickException
         On invalid param.
     """
-    if len(input_urls) == 0 and len(output_urls) == 0:
-        raise click.ClickException("You must specify at least one S3 URL, using --input-url or --output-url.")
+    if len(input_urls) == 0:
+        raise click.ClickException("You must specify at least one S3 URL, using --input-url.")
 
-    for url in input_urls + output_urls:
+    for url in input_urls:
         if not validate_S3_URI(url):
             raise click.ClickException(f"Invalid URL format ({url}).")
         bucket_name, _ = split_S3_URI(url)
@@ -86,7 +80,7 @@ def validate_arguments(profile_name, input_urls, output_urls, expires_in):
         )
 
 
-def make_presigned_urls(profile_name, input_urls, output_urls, expires_in, no_confirmation) -> None:
+def make_presigned_urls(profile_name, input_urls, expires_in, no_confirmation) -> None:
     print(
         """\n"""
         """This action will generate AWS S3 presigned URLs for the input and """
@@ -99,15 +93,6 @@ def make_presigned_urls(profile_name, input_urls, output_urls, expires_in, no_co
 Read (input) URLs:
 ------------------
 {NEWLINE.join(input_urls)}
-"""
-        )
-
-    if len(output_urls) > 0:
-        print(
-            f"""
-Write (output) URLs:
---------------------
-{NEWLINE.join(output_urls)}
 """
         )
 
@@ -119,10 +104,6 @@ Write (output) URLs:
     for url in input_urls:
         input_presigned_urls.append(generate_presigned_input_url(url, expires_in, profile_name))
 
-    output_presigned_urls = []
-    for url in output_urls:
-        output_presigned_urls.append(generate_presigned_output_url(url, expires_in, profile_name))
-
     print(
         f"""Your presigned URLs will expire in {humanfriendly.format_timespan(expires_in)}. """
         """Please launch the McCloud job with these URLs."""
@@ -133,15 +114,6 @@ Write (output) URLs:
 Presigned INPUT URLs:
 ---------------------
 {(NEWLINE+NEWLINE).join(input_presigned_urls)}
-"""
-        )
-
-    if len(output_presigned_urls) > 0:
-        print(
-            f"""
-Presigned OUTPUT URLs:
-----------------------
-{(NEWLINE+NEWLINE).join(output_presigned_urls)}
 """
         )
 
@@ -159,23 +131,3 @@ def generate_presigned_input_url(url: str, expires_in: int, profile_name=None) -
         Params={"Bucket": bucket_name, "Key": object_name},
         ExpiresIn=expires_in,
     )
-
-
-def generate_presigned_output_url(url: str, expires_in: int, profile_name=None) -> str:
-    if not url.startswith("s3://"):
-        # can't presign random URLs!
-        return url
-
-    bucket_name, object_name = split_S3_URI(url)
-    bucket_location = get_bucket_location(bucket_name, profile_name=profile_name)
-    s3 = get_s3_client(profile_name=profile_name, region_name=bucket_location)
-    return s3.generate_presigned_url(
-        ClientMethod="put_object",
-        Params={
-            "Bucket": bucket_name,
-            "Key": object_name,
-            "ContentType": "application/octet-stream",
-        },
-        ExpiresIn=expires_in,
-        HttpMethod="PUT",
-    )
